==> odoo_14.0.0+dfsg.3.orig.tar.xz: odoo-14.0.0+dfsg.3/addons/website_sale/README.md <==
Odoo e-Commerce
---------------

### Optimize sales with an awesome online store.

Odoo is an <a href="https://www.odoo.com/page/e-commerce">Open Source eCommerce</a>
unlike anything you have ever seen before. Get an awesome catalog of products
and great product description pages.

It's full-featured, integrated with your management software, fully
customizable and super easy.

Create Awesome Product Pages
----------------------------

Odoo's unique *'edit inline'* and building blocks approach makes product pages
creation surprisingly easy. "Want to change the price of a product? or put it
in bold? Want to add a banner for a specific product?" just click and change.
What you see is what you get. Really.

Drag & Drop well designed *'Building Blocks'* to create beautifull product
pages that your customer will love.

Increase Your Revenue Per Order
-------------------------------

The built-in cross-selling feature helps you offer extra products related to
what the shopper put in his cart. (e.g. accessories)

Odoo's upselling algorythm allows you to show visitors similar but more
expensive products than the one in view, with incentives.

The inline editing feature allows you to easily change a price, launch a
promotion or fine tune the description of a product, in a just a click.

A Clean Google Analytics Integration
------------------------------------

Get a clear visibility of your sales funnel. Odoo's Google Analytics trackers
are configured by default to track all kind of events related to shopping
carts, call-to-actions, etc.

As Odoo marketing tools (mass mailing, campaigns, etc) are also linked with
Google Analytics, you get a complete view of your business.

Target New Markets
------------------

Get your website translated in multiple languages with no effort. Odoo proposes
and propagates translations automatically across pages.

Our translation "on demand" features allows you to benefit from professional
translators to translate all your changes automatically. Just change any part
of your website (a new blog post, a page modification, product descriptions,
...) and the translated versions are updated automatically in around 32 hours.

Fine Tune Your Catalog
----------------------

Get full control on how you display your products in the catalog page:
promotional ribbons, related size of products, discounts, variants, grid/list
view, etc.

Edit any product inline to make your website evolve with your customer need.

Acquire New Customers
---------------------

SEO tools are ready to use, with no configuration required. Odoo suggests
keywords according to Google most searched terms, Google Analytics tracks your
shopping cart events, sitemap are created automatically for Google indexation,
etc.

We even do structured content automatically to promote your product and events
efficiently in Google.

Leverage Social Media
---------------------

Create new landing pages easily with the Odoo inline editing feature. Send
visitors of your different marketing campaigns to specific landing pages to
optimize conversions.

Manage a Reseller Network
-------------------------

Manage a reseller network to target new market, have local presences or broaden
your distribution. Give them access to your reseller portal for an efficient
collaboration.

Promote your resellers online, forward leads to resellers (with built-in
geolocalisation feature), define specific pricelists, launch a loyalty program
(offer specific discounts to your best customers or resellers), etc.

Benefit from the power of Odoo, in your online store: a powerfull tax engine,
flexible pricing structures, a real inventory management solution, a reseller
interface, support for products with different behaviours; physical goods,
events, services, variants and options, etc.

You don't need to interface with your warehouse, sales or accounting software.
Everything is integrated with Odoo. No pain, real time.

A Clean Checkout Process
------------------------

Convert most visitor interests into real orders with a clean checkout process
with a minimal number of steps and a great useability on every page.

Customize your checkout process to fit your business needs: payment modes,
delivery methods, cross-selling, special conditions, etc.

And much more...
----------------

### Online Sales

-   Mobile Interface
-   Sell products, events or services
-   Flexible pricelists
-   Product multi-variants
-   Multiple stores
-   Great checkout process

### Customer Service

-   Customer Portal to track orders
-   Assisted shopping with website live chats
-   Returns management
-   Advanced shipping rules
-   Coupons or gift certificates

### Order Management

-   Advanced warehouse management features
-   Invoicing and accounting integration
-   Mass mailing and customer segmentations
-   Lead automation and marketing campaigns
-   Persistent shopping cart

Fully Integrated With Other Apps
--------------------------------

### CMS

Easily create awesome websites with no technical knowledge required.

### Blogs

Write news, attract new visitors, build customer loyalty.

### Online Events

Schedule, organize, promote or sell events online; conferences, webinars, trainings, etc.

==> odoo_16.0.0+dfsg.1.orig.tar.xz: odoo-16.0.0+dfsg.1/addons/website_sale/README.md <==
Odoo e-Commerce
---------------

### Optimize sales with an awesome online store.

Odoo is an <a href="https://www.odoo.com/app/ecommerce">Open Source eCommerce</a>
unlike anything you have ever seen before. Get an awesome catalog of products
and great product description pages.

It's full-featured, integrated with your management software, fully
customizable and super easy.

Create Awesome Product Pages
----------------------------

Odoo's unique *'edit inline'* and building blocks approach makes product pages
creation surprisingly easy. "Want to change the price of a product? or put it
in bold? Want to add a banner for a specific product?" just click and change.
What you see is what you get. Really.

Drag & Drop well designed *'Building Blocks'* to create beautifull product
pages that your customer will love.

Increase Your Revenue Per Order
-------------------------------

The built-in cross-selling feature helps you offer extra products related to
what the shopper put in his cart. (e.g. accessories)

Odoo's upselling algorythm allows you to show visitors similar but more
expensive products than the one in view, with incentives.

The inline editing feature allows you to easily change a price, launch a
promotion or fine tune the description of a product, in a just a click.

A Clean Google Analytics Integration
------------------------------------

Get a clear visibility of your sales funnel. Odoo's Google Analytics trackers
are configured by default to track all kind of events related to shopping
carts, call-to-actions, etc.

As Odoo marketing tools (mass mailing, campaigns, etc) are also linked with
Google Analytics, you get a complete view of your business.

Target New Markets
------------------

Get your website translated in multiple languages with no effort. Odoo proposes
and propagates translations automatically across pages.

Our translation "on demand" features allows you to benefit from professional
translators to translate all your changes automatically. Just change any part
of your website (a new blog post, a page modification, product descriptions,
...) and the translated versions are updated automatically in around 32 hours.

Fine Tune Your Catalog
----------------------

Get full control on how you display your products in the catalog page:
promotional ribbons, related size of products, discounts, variants, grid/list
view, etc.

Edit any product inline to make your website evolve with your customer need.

Acquire New Customers
---------------------

SEO tools are ready to use, with no configuration required. Odoo suggests
keywords according to Google most searched terms, Google Analytics tracks your
shopping cart events, sitemap are created automatically for Google indexation,
etc.

We even do structured content automatically to promote your product and events
efficiently in Google.

Leverage Social Media
---------------------

Create new landing pages easily with the Odoo inline editing feature. Send
visitors of your different marketing campaigns to specific landing pages to
optimize conversions.

Manage a Reseller Network
-------------------------

Manage a reseller network to target new market, have local presences or broaden
your distribution. Give them access to your reseller portal for an efficient
collaboration.

Promote your resellers online, forward leads to resellers (with built-in
geolocalisation feature), define specific pricelists, launch a loyalty program
(offer specific discounts to your best customers or resellers), etc.

Benefit from the power of Odoo, in your online store: a powerfull tax engine,
flexible pricing structures, a real inventory management solution, a reseller
interface, support for products with different behaviours; physical goods,
events, services, variants and options, etc.

You don't need to interface with your warehouse, sales or accounting software.
Everything is integrated with Odoo. No pain, real time.

A Clean Checkout Process
------------------------

Convert most visitor interests into real orders with a clean checkout process
with a minimal number of steps and a great useability on every page.

Customize your checkout process to fit your business needs: payment modes,
delivery methods, cross-selling, special conditions, etc.

And much more...
----------------

### Online Sales

-   Mobile Interface
-   Sell products, events or services
-   Flexible pricelists
-   Product multi-variants
-   Multiple stores
-   Great checkout process

### Customer Service

-   Customer Portal to track orders
-   Assisted shopping with website live chats
-   Returns management
-   Advanced shipping rules
-   Coupons or gift certificates

### Order Management

-   Advanced warehouse management features
-   Invoicing and accounting integration
-   Mass mailing and customer segmentations
-   Lead automation and marketing campaigns
-   Persistent shopping cart

Fully Integrated With Other Apps
--------------------------------

### CMS

Easily create awesome websites with no technical knowledge required.

### Blogs

Write news, attract new visitors, build customer loyalty.

### Online Events

Schedule, organize, promote or sell events online; conferences, webinars, trainings, etc.
